@@ -19,8 +19,8 @@ def function_cache(name='default', keys=None, key_prefix=None, **kwargs):
         cache_key_prefix = f'{decorated_func.__module__}.{decorated_func.__name__}-' if _key_prefix is None else _key_prefix
 
         @wraps(decorated_func)
-        def wrapper(*args, **kwargs):
-            cache_key = f'{cache_key_prefix}{cache_backend.compute_key(args, kwargs)}'
+        def wrapper(*wrapped_args, **wrapped_kwargs):
+            cache_key = f'{cache_key_prefix}{cache_backend.compute_key(wrapped_args, wrapped_kwargs)}'
 
             cache_hit = cache_backend.exists(cache_key)
             logger.debug(f'Cache {"hit" if cache_hit else "miss"} for cache key <{cache_key}>.')
@@ -28,9 +28,9 @@ def function_cache(name='default', keys=None, key_prefix=None, **kwargs):
                 return cache_backend.get(cache_key)
 
             if pass_cache_key:
-                result = decorated_func(*args, **kwargs, _cache_key=cache_key)
+                result = decorated_func(*wrapped_args, **wrapped_kwargs, _cache_key=cache_key)
             else:
-                result = decorated_func(*args, **kwargs)
+                result = decorated_func(*wrapped_args, **wrapped_kwargs)
             #end if
 
             cache_backend.put(cache_key, result)
